@@ -68,7 +68,7 @@ def handle_cli_exceptions(function):
             logger.debug(ex)
         except (NoOptionError, NoSectionError) as ex:
             logger.warning(
-                "Configuration missing from config ('%s'). Run 'osducli config update'", ex.args[0]
+                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
             )
         sys.exit(1)
 
@@ -117,7 +117,7 @@ class CliOsduClient(OsduClient):
                 )
             else:
                 logger.error(
-                    "Unknown type of authentication mode %s. Run 'osducli config update'.",
+                    "Unknown type of authentication mode %s. Run 'osdu config update'.",
                     authentication_mode,
                 )
                 sys.exit(2)
@@ -125,7 +125,7 @@ class CliOsduClient(OsduClient):
             super().__init__(server, data_partition, credentials, retries)
         except (NoOptionError, NoSectionError) as ex:
             logger.warning(
-                "Authentication information missing from config ('%s'). Run 'osducli config update'",
+                "Authentication information missing from config ('%s'). Run 'osdu config update'",
                 ex.args[0],
             )
             sys.exit(1)
@@ -172,7 +172,7 @@ class CliOsduClient(OsduClient):
             logger.debug(ex)
         except (NoOptionError, NoSectionError) as ex:
             logger.warning(
-                "Configuration missing from config ('%s'). Run 'osducli config update'", ex.args[0]
+                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
             )
 
         sys.exit(1)
@@ -207,7 +207,7 @@ class CliOsduClient(OsduClient):
             logger.debug(ex)
         except (NoOptionError, NoSectionError) as ex:
             logger.warning(
-                "Configuration missing from config ('%s'). Run 'osducli config update'", ex.args[0]
+                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
             )
 
         sys.exit(1)
@@ -241,7 +241,7 @@ class CliOsduClient(OsduClient):
             logger.debug(ex)
         except (NoOptionError, NoSectionError) as ex:
             logger.warning(
-                "Configuration missing from config ('%s'). Run 'osducli config update'", ex.args[0]
+                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
             )
 
         sys.exit(1)
@@ -306,7 +306,7 @@ class CliOsduClient(OsduClient):
             logger.debug(ex)
         except (NoOptionError, NoSectionError) as ex:
             logger.warning(
-                "Configuration missing from config ('%s'). Run 'osducli config update'", ex.args[0]
+                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
             )
 
         sys.exit(1)
